[−][src]Struct winit::monitor::MonitorHandle
Handle to a monitor.
Allows you to retrieve information about a given monitor and can be used in Window creation.
Methods
impl MonitorHandle[src]
pub fn get_name(&self) -> Option<String>[src]
Returns a human-readable name of the monitor.
Returns None if the monitor doesn't exist anymore.
pub fn get_dimensions(&self) -> PhysicalSize[src]
Returns the monitor's resolution.
pub fn get_position(&self) -> PhysicalPosition[src]
Returns the top-left corner position of the monitor relative to the larger full screen area.
pub fn get_hidpi_factor(&self) -> f64[src]
Returns the DPI factor that can be used to map logical pixels to physical pixels, and vice versa.
See the dpi module for more information.
Platform-specific
- X11: Can be overridden using the
WINIT_HIDPI_FACTORenvironment variable. - Android: Always returns 1.0.